==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Algorithm/IsoProbabilisticTransformation/NatafIndependentCopula/InverseNatafIndependentCopulaEvaluation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  InverseNatafIndependentCopulaEvaluation.cxx
 *  @brief Class for the InverseNataf transformation evaluation for independent
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: InverseNatafIndependentCopulaEvaluation.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "InverseNatafIndependentCopulaEvaluation.hxx"
#include "DistFunc.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      /*
       * @class InverseNatafIndependentCopulaEvaluation
       *
       * This class offers an interface for the InverseNataf function for independent copula
       */

      typedef Distribution::DistFunc DistFunc;

      CLASSNAMEINIT(InverseNatafIndependentCopulaEvaluation);

      /* Parameter constructor */
      InverseNatafIndependentCopulaEvaluation::InverseNatafIndependentCopulaEvaluation(const UnsignedLong dimension):
	NumericalMathEvaluationImplementation(),
	dimension_(dimension)
      {
	Description description;
	for (UnsignedLong i = 0; i < dimension_; ++i)
	  {
	    OSS oss;
	    oss << "x" << i;
	    description.add(oss);
	  }
	for (UnsignedLong i = 0; i < dimension_; ++i)
	  {
	    OSS oss;
	    oss << "y" << i;
	    description.add(oss);
	  }
	setDescription(description);
      }

      /* Virtual constructor */
      InverseNatafIndependentCopulaEvaluation * InverseNatafIndependentCopulaEvaluation::clone() const
      {
	return new InverseNatafIndependentCopulaEvaluation(*this);
      }

      /* String converter */
      String InverseNatafIndependentCopulaEvaluation::str() const
      {
	OSS oss;
	oss << "class=" << InverseNatafIndependentCopulaEvaluation::GetClassName()
	    << " description=" << getDescription()
            << " dimension=" << dimension_;
                   
	return oss;
      }

      /*
       * Evaluation
       * The inverse Nataf transform S reads:
       * Si(u) = Phi(ui), where Phi is the CDF of the standard normal distribution
       */
      InverseNatafIndependentCopulaEvaluation::NumericalPoint InverseNatafIndependentCopulaEvaluation::operator () (const NumericalPoint & in) const
	throw (InvalidArgumentException, InternalException)
      {
	NumericalPoint result(dimension_);
	for (UnsignedLong i = 0; i < dimension_; ++i)
	  {
	    result[i] = DistFunc::pNormal(in[i]);
	  }
	return result;
      }

      /* Gradient according to the marginal parameters. Currently, the dependence parameter are not taken into account. */

      InverseNatafIndependentCopulaEvaluation::Matrix InverseNatafIndependentCopulaEvaluation::parametersGradient(const NumericalPoint & in) const
      {
	return Matrix(0, dimension_);
      }
	  
      /* Accessor for input point dimension */
      UnsignedLong InverseNatafIndependentCopulaEvaluation::getInputNumericalPointDimension() const
	throw(InternalException)
      {
	return dimension_;
      }

      /* Accessor for output point dimension */
      UnsignedLong InverseNatafIndependentCopulaEvaluation::getOutputNumericalPointDimension() const
	throw(InternalException)
      {
	return dimension_;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Uncertainty/Algorithm/IsoProbabilisticTransformation/NatafIndependentCopula/InverseNatafIndependentCopulaEvaluation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  InverseNatafIndependentCopulaEvaluation.cxx
 *  @brief Class for the InverseNataf transformation evaluation for independent
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: InverseNatafIndependentCopulaEvaluation.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "InverseNatafIndependentCopulaEvaluation.hxx"
#include "DistFunc.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      /*
       * @class InverseNatafIndependentCopulaEvaluation
       *
       * This class offers an interface for the InverseNataf function for independent copula
       */

      typedef Distribution::DistFunc DistFunc;

      CLASSNAMEINIT(InverseNatafIndependentCopulaEvaluation);

      /* Parameter constructor */
      InverseNatafIndependentCopulaEvaluation::InverseNatafIndependentCopulaEvaluation(const UnsignedLong dimension):
	NumericalMathEvaluationImplementation(),
	dimension_(dimension)
      {
	Description description;
	for (UnsignedLong i = 0; i < dimension_; ++i)
	  {
	    OSS oss;
	    oss << "x" << i;
	    description.add(oss);
	  }
	for (UnsignedLong i = 0; i < dimension_; ++i)
	  {
	    OSS oss;
	    oss << "y" << i;
	    description.add(oss);
	  }
	setDescription(description);
      }

      /* Virtual constructor */
      InverseNatafIndependentCopulaEvaluation * InverseNatafIndependentCopulaEvaluation::clone() const
      {
	return new InverseNatafIndependentCopulaEvaluation(*this);
      }

      /* String converter */
      String InverseNatafIndependentCopulaEvaluation::__repr__() const
      {
	OSS oss;
	oss << "class=" << InverseNatafIndependentCopulaEvaluation::GetClassName()
	    << " description=" << getDescription()
            << " dimension=" << dimension_;
                   
	return oss;
      }

      /*
       * Evaluation
       * The inverse Nataf transform S reads:
       * Si(u) = Phi(ui), where Phi is the CDF of the standard normal distribution
       */
      InverseNatafIndependentCopulaEvaluation::NumericalPoint InverseNatafIndependentCopulaEvaluation::operator () (const NumericalPoint & in) const
	/* throw (InvalidArgumentException, InternalException) */
      {
	NumericalPoint result(dimension_);
	for (UnsignedLong i = 0; i < dimension_; ++i)
	  {
	    result[i] = DistFunc::pNormal(in[i]);
	  }
	return result;
      }

      /* Gradient according to the marginal parameters. Currently, the dependence parameter are not taken into account. */

      InverseNatafIndependentCopulaEvaluation::Matrix InverseNatafIndependentCopulaEvaluation::parametersGradient(const NumericalPoint & in) const
      {
	return Matrix(0, dimension_);
      }
	  
      /* Accessor for input point dimension */
      UnsignedLong InverseNatafIndependentCopulaEvaluation::getInputDimension() const
	/* throw(InternalException) */
      {
	return dimension_;
      }

      /* Accessor for output point dimension */
      UnsignedLong InverseNatafIndependentCopulaEvaluation::getOutputDimension() const
	/* throw(InternalException) */
      {
	return dimension_;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
